package com.ruoyi.project.business.mapper.contract;

import java.util.List;
import com.ruoyi.project.business.domain.TqContractHistory;
import com.ruoyi.project.business.domain.TqContractLift;
import com.ruoyi.project.business.domain.TqContractLiftHistory;
import org.apache.ibatis.annotations.Param;

/**
 * 合同履历Mapper接口
 * 
 * @author ruoyi
 * @date 2024-08-16
 */
public interface TqContractHistoryMapper 
{
    /**
     * 查询合同履历
     * 
     * @param id 合同履历主键
     * @return 合同履历
     */
    public TqContractHistory selectTqContractHistoryById(Long id);

    public TqContractHistory getContractHistory4Contract(Long id);

    /**
     * 查询合同履历列表
     * 
     * @param tqContractHistory 合同履历
     * @return 合同履历集合
     */
    public List<TqContractHistory> selectTqContractHistoryList(TqContractHistory tqContractHistory);

    /**
     * 新增合同履历
     * 
     * @param tqContractHistory 合同履历
     * @return 结果
     */
    public int insertTqContractHistory(TqContractHistory tqContractHistory);



    /**
     * 修改合同履历
     * 
     * @param tqContractHistory 合同履历
     * @return 结果
     */
    public int updateTqContractHistory(TqContractHistory tqContractHistory);

    /**
     * 删除合同履历
     * 
     * @param id 合同履历主键
     * @return 结果
     */
    public int deleteTqContractHistoryById(Long id);

    /**
     * 批量删除合同履历
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTqContractHistoryByIds(Long[] ids);

    public Long selectVersionByContractNo(@Param("contractNo") String contractNo);
}
